"""List of Resource Categories"""
APPLICATION = "Application"
PERSON = "Person"
CODE = "Code"
IMAGE = "Image"
NOT_AVAILABLE = ""
OTHER = "Other"
TUTORIAL = "Tutorial"

ALL = [
    APPLICATION,
    PERSON,
    CODE,
    IMAGE,
    NOT_AVAILABLE,
    OTHER,
    TUTORIAL,
]
